###############################################################################
# Copyright (c) 2014-2015 Cisco and/or its affiliates.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
###############################################################################
# Tacacs Global Utility Library:
# ---------------------
# tacacs_globallib.rb
#
# This is the utility library for the Tacacs Global provider Beaker test cases
# that contains the common methods used across the Tacacs Server testsuite's
# cases. The library is implemented as a module with related methods and
# constants defined inside it for use as a namespace. All of the methods are
# defined as module methods.
#
# Every Beaker Tacacs Server test case that runs an instance of Beaker::TestCase
# requires TacacsSettingLib module.
#
# The module has a single set of methods:
# A. Methods to create manifests for tacacs_global Puppet provider test cases.
###############################################################################

# Require UtilityLib.rb path.
require File.expand_path('../../lib/utilitylib.rb', __FILE__)

# A library to assist testing tacacs_global resource
module TacacsGlobalLib
  # Group of Constants used in negative tests for tacacs_global provider.
  ENSURE_NEGATIVE = 'unknown'

  # A. Methods to create manifests for tacacs_global Puppet provider test cases.

  # Method to create a manifest for tacacs_global
  # @param none [None] No input parameters exist.
  # @result none [None] Returns no object.
  def self.create_tacacs_global_default
    manifest_str = "cat <<EOF >#{PUPPETMASTER_MANIFESTPATH}
node default {
  tacacs_global { 'default':
    key               => 'unset',
    source_interface  => 'unset',
    timeout           => '5',
  }
}
EOF"
    manifest_str
  end

  # Method to create a manifest for tacacs_global resource
  # with a few changes made from above.
  # @param intf [String] source_interface
  # @result none [None] Returns no object.
  def self.create_tacacs_global_non_default(intf)
    manifest_str = "cat <<EOF >#{PUPPETMASTER_MANIFESTPATH}
node default {
  tacacs_global { 'default':
    key                 => '44444444',
    key_format          => '7',
    source_interface    => '#{intf}',
    timeout             => '1',
  }
}
EOF"
    manifest_str
  end
end
